@@ -14,6 +14,8 @@
 #include "kitasubjectview.h"
 #include "kitaboardview.h"
 #include "kitacacheinfo.h"
+#include "kitathreadtabwidget.h"
+#include "kitasubjecttabwidget.h"
 
 #include "libkita/thread.h"
 #include "libkita/favoritethreads.h"
@@ -23,6 +25,7 @@
 #include <qpainter.h>
 #include <qpaintdevicemetrics.h>
 #include <qtextcodec.h>
+#include <qevent.h>
 
 #include <klineedit.h>
 #include <kglobal.h>
@@ -39,6 +42,7 @@
 #include <kurlrequesterdlg.h>
 #include <krun.h>
 #include <kstandarddirs.h>
+#include <kdebug.h>
 
 #include <kedittoolbar.h>
 
@@ -86,6 +90,10 @@ KitaMainWindow::KitaMainWindow()
   connect( m_subjectView, SIGNAL( signalShowThread( const Kita::Thread& ) ),
            m_threadView, SLOT( showThread( const Kita::Thread& ) ) );
 
+  // ad-hoc
+  connect( m_subjectView, SIGNAL( signalShowThreadWithNewTab( const Kita::Thread& ) ),
+           m_threadView, SLOT( showThreadWithNewTab( const Kita::Thread& ) ) );
+
   connect( m_threadView, SIGNAL( thread(const Kita::Thread& ) ),
                          SLOT( updateThreadCache( const Kita::Thread& ) ) );
 
@@ -150,6 +158,7 @@ void KitaMainWindow::setupActions()
 {
   KStdAction::openNew(this, SLOT(fileNew()), actionCollection());
   KStdAction::quit(kapp, SLOT(quit()), actionCollection());
+  KStdAction::copy( this, SLOT( slotEditCopy() ), actionCollection() );
 
   m_toolbarAction = KStdAction::showToolbar(this,
                                             SLOT(optionsShowToolbar()),
@@ -195,7 +204,7 @@ void KitaMainWindow::setupActions()
 
 void KitaMainWindow::slotUrlLine()
 {
-  qDebug(__func__);
+  kdDebug() << __func__;
 }
 
 void KitaMainWindow::writeConfig(KConfig *config)
@@ -415,7 +424,7 @@ void KitaMainWindow::setupView()
 {
   KDockWidget* mainDock;
   mainDock = createDockWidget( "main", 0L, 0L, i18n("main") );
-  m_threadView = new KitaThreadView( mainDock );
+  m_threadView = new KitaThreadTabWidget( mainDock );
   mainDock->setWidget( m_threadView );
   mainDock->setDockSite( KDockWidget::DockFullSite );
   mainDock->setEnableDocking( KDockWidget::DockNone );
@@ -423,7 +432,8 @@ void KitaMainWindow::setupView()
                          SLOT( slotOpenURLRequest( const KURL&, const KParts::URLArgs& ) ) );
 
   m_subjectDock = createDockWidget( "subject", 0L, 0L, i18n("subject") );
-  m_subjectView = new KitaSubjectView( m_subjectDock );
+//  m_subjectView = new KitaSubjectView( m_subjectDock );
+  m_subjectView = new KitaSubjectTabWidget( m_subjectDock );
   m_subjectDock->setWidget( m_subjectView );
   m_subjectDock->setDockSite( KDockWidget::DockFullSite );
 
@@ -446,7 +456,8 @@ void KitaMainWindow::slotOpenURLRequest(const KURL& url, const KParts::URLArgs&)
 
 void KitaMainWindow::updateThreadCache( const Kita::Thread& thread )
 {
-  KitaCacheInfo::getInstance()->setVestedNum( thread.datURL(), thread.resNum() );
+  KitaCacheInfo::getInstance()->setReadNum( thread.datURL(), thread.resNum() );
+  KitaCacheInfo::getInstance()->setResNum( thread.datURL(), thread.resNum() );
 }
 
 void KitaMainWindow::loadCache()
@@ -494,12 +505,13 @@ void KitaMainWindow::setUrl(const KURL& url)
 
 void KitaMainWindow::bookmark( const Kita::Thread& thread, bool on )
 {
+  Kita::Thread* t = new Kita::Thread( thread.getBoard(), thread.datURL(), thread.name(), thread.resNum() );
   FavoriteThreads* favorite = FavoriteThreads::getInstance();
 
   if( on ) {
-    favorite->insert( thread );
+    favorite->insert( t );
   } else {
-    favorite->remove( thread.datURL().prettyURL() );
+    favorite->remove( t->datURL().url() );
   }
 }
 
@@ -528,4 +540,14 @@ void KitaMainWindow::slotThread( const Kita::Thread& thread )
   setCaption( thread.name() );
 }
 
+void KitaMainWindow::slotEditCopy()
+{
+  QWidget* widget = kapp->focusWidget();
+
+  if( widget ) {
+    QKeyEvent e( QEvent::KeyPress, Key_C, 'C', ControlButton );
+    QApplication::sendEvent( widget, &e );
+  }
+}
+
 #include "kita.moc"
