@@ -15,6 +15,10 @@
 #include <qstringlist.h>
 #include <qregexp.h>
 #include <klistview.h>
+#include <kpopupmenu.h>
+#include <klocale.h>
+#include <krun.h>
+#include <kdebug.h>
 #include <qvaluelist.h>
 
 #include "libkita/qcp932codec.h"
@@ -31,6 +35,8 @@ KitaBoardView::KitaBoardView(QWidget *parent, const char *name)
   m_boardList->setSorting(-1);
   m_boardList->addColumn("name");
   connect(m_boardList, SIGNAL(executed(QListViewItem*)), SLOT( loadBoard(QListViewItem*) ));
+  connect( m_boardList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
+                        SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
 }
 
 KitaBoardView::~KitaBoardView()
@@ -66,7 +72,7 @@ bool KitaBoardView::isBoardUrl(const KURL& url) const
 
   if ( url.isEmpty() ) return false;
 
-  QString str = url.prettyURL();
+  QString str = url.url();
 
   if ( url_2ch.search(str) == -1 && url_bbspink.search(str) == -1 ) return false;
   if ( url_www_2ch.search(str) != -1 ) return false;
@@ -112,7 +118,7 @@ void KitaBoardView::loadBoardList()
     for(QValueListIterator<Kita::Board> it = board_list.begin(); it != board_list.end(); ++it)
     {
       Kita::Board board = (*it);
-      previousBoard = new KListViewItem(categoryItem, previousBoard, board.name(), board.url().prettyURL());
+      previousBoard = new KListViewItem(categoryItem, previousBoard, board.name(), board.url().url());
     }
     previous = categoryItem;
   }
@@ -121,7 +127,9 @@ void KitaBoardView::loadBoardList()
 QPtrList<Kita::Category> KitaBoardView::getCategoryList(const QString& html) const
 {
   QPtrList<Kita::Category> result;
-  result.setAutoDelete( true );
+
+  // XXX: maybe crash 
+  //  result.setAutoDelete( true );
 
   QStringList lines = QStringList::split("\n", html);
   QStringList::iterator it;
@@ -153,9 +161,9 @@ void KitaBoardView::printCateogryList(QPtrList<Kita::Category>& list)
     QValueList<Kita::Board> board_list = category->getBoardList();
     QValueListIterator<Kita::Board> it2;
     for(it2 = board_list.begin(); it2 != board_list.end(); ++it2) {
-      qDebug("category:%s name:%s url:%s", (const char *)category->name().local8Bit(),
-      (const char*)(*it2).name().local8Bit(),
-      (*it2).url().prettyURL().latin1());
+      kdDebug() << "category:" << category->name()
+      << "name:" << (const char*)(*it2).name()
+      << "url:" << (*it2).url().url() << endl;
     }
   }
 }
@@ -177,3 +185,27 @@ void KitaBoardView::setFont( const QFont& font )
 {
   m_boardList->setFont(font);
 }
+
+void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint& point, int )
+{
+  if( item == 0 ) {
+    return;
+  }
+
+  KPopupMenu popup( 0 );
+  popup.insertItem( i18n("Open with Web Browser"), 0 );
+  popup.insertItem( i18n("Open with new tab(broken)"), 1 );
+
+  KURL url = item->text(1);
+
+  switch( popup.exec( point ) ) {
+  case 0:
+    KRun::runURL( url, "text/html" );
+    break;
+  case 1:
+//    emit signalShowThreadWithNewTab( thread );
+    break;
+  default:
+    break;
+  }
+}
