@@ -14,6 +14,7 @@
 #include <qtextcodec.h>
 #include <qregexp.h>
 #include <qfile.h>
+#include <qclipboard.h>
 
 // kdelibs/kio
 #include <kio/slaveconfig.h>
@@ -39,7 +40,7 @@ enum SubjectViewRows {
   Row_Icon,
   Row_Subject,
   Row_ResNum,
-  Row_Vested,
+  Row_Read,
   Row_Unread,
   Row_DatName,
   Row_DatURL
@@ -57,7 +58,7 @@ KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
   subjectList->addColumn("");
   subjectList->addColumn(i18n("Title"));
   subjectList->addColumn(i18n("ResNum"));
-  subjectList->addColumn(i18n("Vested"));
+  subjectList->addColumn(i18n("ReadNum"));
   subjectList->addColumn(i18n("Unread"));
   subjectList->addColumn(i18n("Dat"));
 
@@ -66,11 +67,7 @@ KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
 
   connect( SearchButton, SIGNAL( clicked() ), SLOT( slotSearchButton() ) );
   connect( SearchCombo, SIGNAL( activated(int) ), SLOT( slotSearchButton() ) );
-  connect(this, SIGNAL(signalSubjectListClicked(QListViewItem*)), subjectList, SIGNAL(clicked(QListViewItem*)));
   connect( HideButton, SIGNAL( toggled(bool) ), SLOT( slotHideButton(bool) ) );
-  connect( m_subjectTab, SIGNAL( currentChanged(QWidget*) ), SLOT( slotCurrentChanged(QWidget*) ) );
-  connect( m_favoriteListView, SIGNAL( signalShowThread( const Kita::Thread& ) ),
-                               SIGNAL( signalShowThread( const Kita::Thread& ) ) );
   connect( subjectList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
                         SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
   connect( subjectList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
@@ -93,11 +90,11 @@ void KitaSubjectView::loadThread( int, QListViewItem* item )
   KURL datURL = m_board.url();
   datURL.addPath("/dat/" + datName);
 
-  Kita::Thread thread( m_board, datURL );
-  thread.setName( item->text( Row_Subject ) );
-  thread.setResNum( item->text( Row_Vested ).toInt() );
+  Kita::Thread* thread = new Kita::Thread( m_board, datURL,
+                                           item->text( Row_Subject ),
+                                           item->text( Row_Read ).toInt() );
 
-  emit signalShowThread( thread );
+  emit signalShowThread( *thread );
 }
 
 void KitaSubjectView::loadBoard(const Kita::Board& board)
@@ -112,30 +109,27 @@ void KitaSubjectView::loadBoard(const Kita::Board& board)
   m_board = board;
 
   KitaCacheInfo* cache = KitaCacheInfo::getInstance();
-  m_threadList = m_board.getThreadList();
+  QPtrList<Kita::Thread> threadList = m_board.getThreadList();
 
   // clear list
   subjectList->clear();
 
-  for(unsigned i=0; i<m_threadList.count(); i++) {
-    Kita::Thread* thread = m_threadList.at(i);
+  for(unsigned i=0; i<threadList.count(); i++) {
+    Kita::Thread* thread = threadList.at(i);
 
-    int vested = cache->getVestedNum(thread->datURL());
-    new KListViewItem(subjectList,
-                      QString("%1").arg(i+1, 4),
-                      "",
-                      thread->name(),
-                      QString("%1").arg(thread->resNum(), 4),
-                      (vested > 0) ? QString::number(vested) : QString(""),
-                      (vested > 0 && thread->resNum() != vested) ? QString::number(thread->resNum() - vested) : QString(""),
-                      thread->datURL().fileName(),
-                      thread->datURL().prettyURL());
+    int readNum = cache->readNum( thread->datURL() );
+    int resNum = thread->resNum();
+    new KListViewItem( subjectList,
+                       QString("%1").arg(i+1, 4),
+                       "",
+                       thread->name(),
+                       QString("%1").arg( resNum, 4 ),
+                       (readNum > 0) ? QString::number(readNum) : QString(""),
+                       (readNum > 0 && resNum != readNum) ? QString::number( resNum - readNum ) : QString(""),
+                       thread->datURL().fileName(),
+                       thread->datURL().url() );
   }
 
-  // set tab label
-  // XXX
-  m_subjectTab->setTabLabel( m_subjectTab->page( 0 ), m_board.name() );
-
   if( HideButton->isOn() ) {
     HideButton->toggle();
   }
@@ -240,22 +234,15 @@ void KitaSubjectView::setFont( const QFont& font )
 void KitaSubjectView::updateThread(const Kita::Thread& updated_thread)
 {
   for(QListViewItem* item = subjectList->firstChild(); item; item = item->nextSibling() ) {
-    if( item->text(Row_DatURL) == updated_thread.datURL().prettyURL() ) {
+    if( item->text(Row_DatURL) == updated_thread.datURL().url() ) {
       int resNum = item->text( Row_ResNum ).toInt();
-      int vested = updated_thread.resNum();
-      item->setText( Row_Vested, QString::number( vested ) );
-      item->setText( Row_Unread, vested > 0 && resNum != vested ? QString::number(resNum - vested) : QString(""));
+      int readNum = updated_thread.resNum();
+      item->setText( Row_Read, QString::number( readNum ) );
+      item->setText( Row_Unread, readNum > 0 && resNum != readNum ? QString::number(resNum - readNum) : QString(""));
     }
   }
 }
 
-void KitaSubjectView::slotCurrentChanged(QWidget* widget)
-{
-  if( QString::compare(widget->name(), "favoriteTab") == 0 ) {
-    m_favoriteListView->update();
-  }
-}
-
 void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoint& point, int )
 {
   if( item == 0 ) {
@@ -264,19 +251,30 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
 
   KPopupMenu popup( 0 );
   popup.insertItem( i18n("Open with Web Browser"), 0 );
+  popup.insertItem( i18n("Open with new tab"), 1 );
+  popup.insertItem( i18n("Copy title and URL"), 2 );
 
   QString datName = item->text(Row_DatName);
   KURL datURL = m_board.url();
   datURL.addPath("/dat/" + datName);
 
   Kita::Thread thread( m_board, datURL );
+  thread.setName( item->text( Row_Subject ) );
+  thread.setResNum( item->text( Row_Read ).toInt() );
+
+  QClipboard* clipboard = QApplication::clipboard();
 
   switch( popup.exec( point ) ) {
   case 0:
     KRun::runURL( thread.url(), "text/html" );
     break;
+  case 1:
+    emit signalShowThreadWithNewTab( thread );
+    break;
+  case 2:
+    clipboard->setText( thread.name() + "\n" + thread.url().url() );
+    break;
   default:
     break;
   }
 }
-
