@@ -12,6 +12,7 @@
 
 #include <kio/slaveconfig.h>
 #include <kio/netaccess.h>
+#include <kdebug.h>
 
 #include <kfilterdev.h>
 
@@ -35,7 +36,11 @@ Board::~Board()
 
 const KURL Board::subjectTxtURL() const
 {
-  return KURL(m_boardURL, "./subject.txt");
+  if( m_boardURL.isEmpty() ) {
+    return KURL();
+  } else {
+    return KURL(m_boardURL, "./subject.txt");
+  }
 }
 
 const KURL& Board::url() const
@@ -55,9 +60,13 @@ const QString Board::id() const
 
 const QPtrList<Thread> Board::getThreadList() const
 {
+  if( m_boardURL.isEmpty() ) {
+    kdWarning() << "Waring: board url is empty!" << endl;
+    return QPtrList<Thread>();
+  }
   QPtrList<Thread> threadList;
 
-  KIO::SlaveConfig::self()->setConfigData("http", m_boardURL.host() , "UserAgent", "Monazilla/1.00 (Kita/0.51)");
+  KIO::SlaveConfig::self()->setConfigData("http", m_boardURL.host() , "UserAgent", "Monazilla/1.00 (Kita/0.61)");
   QString tmpFile;
   if(KIO::NetAccess::download(subjectTxtURL(), tmpFile)) {
     QIODevice* tmpDevice = KFilterDev::deviceForFile(tmpFile, "application/x-gzip");
@@ -95,7 +104,7 @@ const QString Board::toXmlFragment() const
   QString ret;
 
   ret += "<board xmlns=\"http://kita.sourceforge.jp/ns/board\">\n";
-  ret += QString("<url>%1</url>\n").arg( m_boardURL.prettyURL() );
+  ret += QString("<url>%1</url>\n").arg( m_boardURL.url() );
   ret += QString("<name>%1</name>\n").arg( m_boardName );
   ret += "</board>\n";
 
@@ -116,21 +125,29 @@ Board Board::fromXml( const QString& xml )
   if( parser.isValid() ) {
     board = parser.getBoard();
   } else {
-    qDebug("inValid");
+    kdError() << "inValid" << endl;
   }
   return board;
 }
 
 bool Board::test()
 {
-  qDebug("Board::test()");
+  kdDebug() << "Board::test()" << endl;
   Board board = Board::fromXml( "<board>\n<url>http://pc.2ch.net/linux/</url>\n<name>Linux</name>\n</board>\n" );
-  if( board.url().prettyURL() != "http://pc.2ch.net/linux/" ) qDebug("inValid: line=%d", __LINE__);
-  if( board.name() != "Linux" ) qDebug("inValid: line=%d", __LINE__);
+  if( board.url().url() != "http://pc.2ch.net/linux/" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( board.name() != "Linux" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
 
   board = Board::fromXml( "  <board>\n    <url>http://pc.2ch.net/linux/</url>\n    <name>Linux</name>\n  </board>\n" );
-  if( board.url().prettyURL() != "http://pc.2ch.net/linux/" ) qDebug("inValid: line=%d", __LINE__);
-  if( board.name() != "Linux" ) qDebug("inValid: line=%d", __LINE__);
+  if( board.url().url() != "http://pc.2ch.net/linux/" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( board.name() != "Linux" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
 
   return true;
 }
