@@ -14,6 +14,7 @@
 #include <kio/slaveconfig.h>
 #include <kio/jobclasses.h>
 #include <kio/scheduler.h>
+#include <kdebug.h>
 
 #include <qwidget.h>
 #include <qapplication.h>
@@ -23,6 +24,8 @@
 
 using namespace Kita;
 
+ThreadFactory* ThreadFactory::instance = 0;
+
 Thread::Thread() : m_board( 0 )
 {
 }
@@ -30,6 +33,8 @@ Thread::Thread() : m_board( 0 )
 Thread::Thread(const Board& board, const KURL& datURL, const QString threadName, int resNum)
   : m_datURL(datURL), m_threadName(threadName), m_resNum(resNum)
 {
+  Q_ASSERT( datURL.url().right( 3 ) == QString( "dat" ) );
+
   m_datID = m_datURL.filename().section(".", 0, 0);
   m_board = new Board( board.url(), board.name() );
   m_boardID = m_board->id();
@@ -119,7 +124,7 @@ const QString Thread::toXmlFragment() const
   QString ret;
 
   ret += "<thread xmlns=\"http://kita.sourceforge.jp/ns/thread\">\n";
-  ret += QString("<daturl>%1</daturl>\n").arg( m_datURL.prettyURL() );
+  ret += QString("<daturl>%1</daturl>\n").arg( m_datURL.url() );
   ret += QString("<name>%1</name>\n").arg( m_threadName );
   ret += QString("<resnum>%1</resnum>\n").arg( m_resNum );
   ret += m_board->toXmlFragment();
@@ -142,7 +147,7 @@ Thread Thread::fromXml( const QString& xml )
   if( parser.isValid() ) {
     thread = parser.getThread();
   } else {
-    qDebug("inValid");
+    kdError() << "inValid" << endl;
   }
 
   return thread;
@@ -150,7 +155,7 @@ Thread Thread::fromXml( const QString& xml )
 
 bool Thread::test()
 {
-  qDebug("Thread::test()");
+  kdDebug() << "Thread::test()" << endl;
   Thread thread = Thread::fromXml( "<thread xmlns=\"http://kita.sourceforge.jp/ns/thread\">\n"
                                    "<daturl>http://pc.2ch.net/linux/dat/1022744633.dat</daturl>\n"
                                    "<name>2ch browser thread</name>\n"
@@ -160,23 +165,49 @@ bool Thread::test()
                                    "<name>Linux</name>\n"
                                    "</board>\n"
                                    "</thread>\n" );
-  if( thread.datURL().prettyURL() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.url().prettyURL() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.name() != "2ch browser thread" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.resNum() != 700 ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.getBoard()->url().prettyURL() != "http://pc.2ch.net/linux/" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.getBoard()->name() != "Linux" ) qDebug("inValid: line=%d", __LINE__);
+
+  // TODO: ǻȤƤkdErrorλϲȤ
+  if( thread.datURL().url() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.url().url() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.name() != "2ch browser thread" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.resNum() != 700 ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.getBoard()->url().url() != "http://pc.2ch.net/linux/" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.getBoard()->name() != "Linux" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
 
   Thread thread2 = Thread::fromXml( thread.toXmlFragment() );
 
-  if( thread2.datURL().prettyURL() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread2.url().prettyURL() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread2.name() != "2ch browser thread" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread2.resNum() != 700 ) qDebug("inValid: line=%d", __LINE__);
-  if( thread2.getBoard()->url().prettyURL() != "http://pc.2ch.net/linux/" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread2.getBoard()->name() != "Linux" ) qDebug("inValid: line=%d", __LINE__);
+  if( thread2.datURL().url() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread2.url().url() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread2.name() != "2ch browser thread" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread2.resNum() != 700 ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread2.getBoard()->url().url() != "http://pc.2ch.net/linux/" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread2.getBoard()->name() != "Linux" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
 
-  qDebug( "%s", thread.toXmlFragment().latin1() );
+  kdDebug() << thread.toXmlFragment() << endl;
 
   thread = Thread::fromXml( "<thread xmlns=\"http://kita.sourceforge.jp/ns/thread\">\n"
                             "  <daturl>http://pc.2ch.net/linux/dat/1022744633.dat</daturl>\n"
@@ -187,12 +218,25 @@ bool Thread::test()
                             "    <name>Linux</name>\n"
                             "  </board>\n"
                             "</thread>\n" );
-  if( thread.datURL().prettyURL() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.url().prettyURL() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.name() != "2ch browser thread" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.resNum() != 700 ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.getBoard()->url().prettyURL() != "http://pc.2ch.net/linux/" ) qDebug("inValid: line=%d", __LINE__);
-  if( thread.getBoard()->name() != "Linux" ) qDebug("inValid: line=%d", __LINE__);
+
+  if( thread.datURL().url() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.url().url() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.name() != "2ch browser thread" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.resNum() != 700 ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.getBoard()->url().url() != "http://pc.2ch.net/linux/" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
+  if( thread.getBoard()->name() != "Linux" ) {
+    kdError() << "inValid: line=" << __LINE__ << endl;
+  }
 
   return true;
 }
@@ -271,7 +315,7 @@ QString ThreadAccess::get()
 {
   if ( m_thread.datURL().protocol() != "k2ch" ) {
     KIO::SlaveConfig::self()->setConfigData("http", m_thread.datURL().host() ,
-                                          "UserAgent", "Monazilla/1.00 (Kita/0.51)");
+                                          "UserAgent", "Monazilla/1.00 (Kita/0.61)");
   }
 
   KIO::TransferJob* job = KIO::get(m_thread.datURL(), true, true);
@@ -288,10 +332,7 @@ QString ThreadAccess::get()
   enter_loop();
 
   QCp932Codec codec;
-  QTextStream stream(m_threadData, IO_ReadOnly);
-  stream.setCodec(&codec);
-
-  return stream.read();
+  return codec.toUnicode( m_threadData );
 }
 
 // from netaccess.cpp
@@ -309,7 +350,7 @@ void ThreadAccess::enter_loop()
 
 void ThreadAccess::slotRedirection(KIO::Job *, const KURL & newURL)
 {
-  qDebug("  Redirected to newURL: %s\n", newURL.url().latin1() );
+  kdDebug() << "Redirected to newURL: " << newURL.url() << endl;
   m_thread = Kita::Thread( m_thread.getBoard(), newURL);
   emit redirection( newURL.url() );
 }
@@ -336,4 +377,23 @@ void ThreadAccess::killJob()
   if( m_currentJob ) m_currentJob->kill();
 }
 
+void ThreadFactory::insertThread( Thread& thread )
+{
+  if( ! instance ) {
+    instance = new ThreadFactory();
+  }
+
+  Thread* new_thread = new Thread( thread.getBoard(), thread.datURL(), thread.name(), thread.resNum() );
+  instance->m_dict.insert( thread.datURL().url(), new_thread );
+}
+
+Thread* ThreadFactory::getThread( QString& datURL )
+{
+  if( ! instance ) {
+    instance = new ThreadFactory();
+  }
+
+  return instance->m_dict[ datURL ];
+}
+
 #include "thread.moc"
