@@ -9,38 +9,31 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include <qtextstream.h>
-#include <qlayout.h>
-#include <qtoolbutton.h>
-#include <qsjiscodec.h>
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qprogressdialog.h>
-#include <qcursor.h>
-
-#include <time.h>
+#include "kitathreadview.h"
 
 #include <kurl.h>
-#include <kio/slaveconfig.h>
-#include <kio/jobclasses.h>
-#include <kio/scheduler.h>
-
 #include <khtmlview.h>
-#include <dom/html_element.h>
-#include <dom/html_inline.h>
-#include <dom/html_base.h>
-#include <dom/html_misc.h>
-#include <dom/html_list.h>
-
-#include <kglobal.h>
-#include <kconfig.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kaction.h>
 #include <kmessagebox.h>
+#include <kdebug.h>
+
+#include <dom/html_inline.h>
+#include <dom/html_base.h>
+#include <dom/html_list.h>
+
+#include <qlayout.h>
+#include <qtoolbutton.h>
+#include <qlabel.h>
+#include <qcombobox.h>
+#include <qprogressdialog.h>
+#include <qcursor.h>
+#include <qtextbrowser.h>
+#include <qmessagebox.h>
+#include <qdatetime.h>
 
 #include "kitahtmlpart.h"
-#include "kitathreadview.h"
 #include "kitawritedialog.h"
 #include "../kitacacheinfo.h"
 #include "kita2ch.h"
@@ -49,8 +42,6 @@
 #include "libkita/qcp932codec.h"
 #include "libkita/favoritethreads.h"
 
-#include <qmessagebox.h>
-
 #define MAX_LABEL_LENGTH 60
 
 static const char* cookie_title = "񤭹߳ǧ";
@@ -67,6 +58,7 @@ static const char* kokomade_yonda = "<p style=\"background-color: #CCCCCC; text-
 
 KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
     : KitaThreadViewBase(parent, name)
+    , m_access( 0 )
     , m_parent( parent )
     , m_popup( 0 )
 {
@@ -119,11 +111,16 @@ KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
 
 KitaThreadView::~KitaThreadView() {}
 
-const QString KitaThreadView::threadSubject() const
+const QString KitaThreadView::threadName() const
 {
   return m_thread.name();
 }
 
+const KURL KitaThreadView::threadURL() const
+{
+  return m_thread.url();
+}
+
 void KitaThreadView::slotDOMNodeActivated(const DOM::Node &node)
 {
   { //process Anchor tags. Anchor tags not proccessed here cause 'emit KParts::BrowserExtention::openURLRequest()'
@@ -131,7 +128,7 @@ void KitaThreadView::slotDOMNodeActivated(const DOM::Node &node)
 
     if ( ! anchor.href().isEmpty() )
     {
-      qDebug("  AnchorNodeActivated:: \n" );
+      kdDebug() << "AnchorNodeActivated::" << endl;
     } // end: anchor.href().isEmpty()
   } // end of Anchor tags.
 }
@@ -159,7 +156,7 @@ int KitaThreadView::getServerTimeFromHttpHeaders( const QString& headers )
   QString dateStr = headerList.grep(regexp)[0];
   if(regexp.search(dateStr) == -1) {
     // invalid date format
-    return time(NULL);
+    return QDateTime::currentDateTime().toTime_t();
   } else {
     // I hate this format ;p
     QString usLocalDateStr = regexp.cap(1) + " " + regexp.cap(3) + " " +
@@ -187,7 +184,6 @@ void KitaThreadView::setSubjectLabel(const QString& boardName, const QString& th
 void KitaThreadView::update( const QString& result )
 {
   QStringList lines = QStringList::split( "\n", result );
-  QString line;
   QString text;
   int num = 0;
 
@@ -205,12 +201,14 @@ void KitaThreadView::update( const QString& result )
   text += "</head><body>";
 
   for( QStringList::iterator it = lines.begin(); it != lines.end(); ++it ) {
-    line = (*it);
-    Kita::Comment comment(line);
-    if( comment.isValid() == false) {
+    QString line = (*it);
+
+    if( line.isEmpty() ) {
       continue;
     }
 
+    Kita::Comment comment(line);
+
     num++;
     if(num == 1) {
       m_thread.setName(comment.getSubject());
@@ -251,7 +249,7 @@ void KitaThreadView::updateButton()
   if ( HighLightButton->isOn() ) {
     HighLightButton->toggle();
   }
-  if( FavoriteThreads::getInstance()->contains( m_thread.datURL().prettyURL() ) ) {
+  if( FavoriteThreads::getInstance()->contains( m_thread.datURL().url() ) ) {
     BookmarkButton->setOn( true );
   } else {
     BookmarkButton->setOn( false );
@@ -270,12 +268,13 @@ const QString KitaThreadView::footer( int prevResNum ) const
 
   return text;
 }
+
 void KitaThreadView::slotShowErrorDialog( const QString& input, const KURL& )
 {
-  qDebug("#%s#", (const char *)input.local8Bit());
+  kdDebug() << "'" << input << "'" << endl;
   Kita::WriteResult writeResult(input);
 
-  qDebug("code = %d", writeResult.code());
+  kdDebug() << "code = " << writeResult.code() << endl;
   switch( writeResult.code() ) {
   case Kita::K2ch_Unknown:
     // probably OK.
@@ -305,7 +304,7 @@ void KitaThreadView::slotShowErrorDialog( const QString& input, const KURL& )
 
 KitaWriteDialog* KitaThreadView::openDialog( const Kita::PostInfo& info )
 {
-  KitaWriteDialog* new_dialog = KitaWriteDialog::open( info );
+  KitaWriteDialog* new_dialog = KitaWriteDialog::open( info, m_thread.boardName(), m_thread.name() );
   connect( new_dialog, SIGNAL( postStarted( KIO::Job *, const Kita::PostInfo& ) ),
            this, SLOT( slotPostStarted( KIO::Job*, const Kita::PostInfo&) ) );
   connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
@@ -317,7 +316,7 @@ KitaWriteDialog* KitaThreadView::openDialog( const Kita::PostInfo& info )
 
 void KitaThreadView::slotWriteButtonClicked()
 {
-  QSjisCodec cp932Codec;
+//  QSjisCodec cp932Codec;
   KURL bbscgiURL = KURL( m_thread.boardUrl(), "../test/bbs.cgi");
   bbscgiURL.setProtocol( "http" );
 
@@ -347,16 +346,13 @@ void KitaThreadView::slotHighLightenButton(bool yes)
 
 void KitaThreadView::insertSearchCombo()
 {
-  int count;
-  bool found = false;
-
-  for( count = 0; count < SearchCombo->count(); ++count ) {
-    if ( SearchCombo->text( count ) ==  SearchCombo->currentText() ) {
-      found = true;
-      break;
+  for( int count = 0; count < SearchCombo->count(); ++count ) {
+    if ( SearchCombo->text( count ) == SearchCombo->currentText() ) {
+      // found
+      return;
     }
   }
-  if ( ! found ) SearchCombo->insertItem( SearchCombo->currentText() );
+  SearchCombo->insertItem( SearchCombo->currentText() );
 }
 
 QStringList KitaThreadView::parseSearchQuery(const QString &input) const
@@ -448,13 +444,11 @@ void KitaThreadView::slotPopupMenu( KXMLGUIClient *client, const QPoint &global,
   KActionCollection * collection = client->actionCollection();
   KAction * action;
   action = new KAction( i18n("goback anchor"), SmallIcon("idea"), KShortcut(), m_threadPart, SLOT( gobackAnchor() ), collection, "goback_anchor" );
-//  qDebug("  KitaThreadView::slotPopupMenu() %p\n", action);
   emit popupMenu(client, global, url, mimeType, mode);
 }
 
 void KitaThreadView::slotOpenURLRequest(const KURL& url, const KParts::URLArgs& args)
 {
-  qDebug(" openURLRequest:: orgURL %s\n", url.url().latin1() );
   if ( url.url().at(0) == '#' ) {
     m_threadPart->gotoAnchor( url.ref() );
     return;
@@ -494,7 +488,7 @@ KURL KitaThreadView::filterReadCGI(const KURL& url)
       else newURL.setRef( refBase );
     }
   }
-  qDebug("    newURL: %s\n", newURL.url().latin1() );
+  kdDebug() << "newURL: " << newURL.url() << endl;
   return newURL;
 }
 
@@ -520,9 +514,4 @@ void KitaThreadView::killJob()
     m_access->killJob();
   }
 }
-
-KParts::BrowserExtension* KitaThreadView::browserExtension()
-{
-  return m_threadPart->browserExtension();
-}
 // vim:sw=2:
